%define dist .el5
%define unmangled_name setproctitle
%define name python-setproctitle
%define version 1.1.3
%define python python
%{?with_python:%define python %{with_python}}

%define pyver %(%{python} -c "import sys; print '%s.%s' % sys.version_info[:2]")
%define release 1.py%{pyver}

%define __os_install_post    \
    /usr/lib/rpm/redhat/brp-compress \
    %{!?__debug_package:/usr/lib/rpm/redhat/brp-strip %{__strip}} \
    /usr/lib/rpm/redhat/brp-strip-static-archive %{__strip} \
    /usr/lib/rpm/redhat/brp-strip-comment-note %{__strip} %{__objdump} \
    /usr/lib/rpm/redhat/brp-java-repack-jars \
%{nil}


Summary: Allow customization of the process title.
Name: %{name}
Version: %{version}
Release: %{release}%{dist}
Source0: %{unmangled_name}-%{version}.tar.gz
License: BSD
Group: Development/Libraries
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires: python-devel
Prefix: %{_prefix}
Vendor: Daniele Varrazzo <daniele.varrazzo@gmail.com>
Url: http://code.google.com/p/py-setproctitle/

%description
A ``setproctitle`` implementation for Python
============================================

:author: Daniele Varrazzo

The library allows a process to change its title (as displayed by system tools
such as ``ps`` and ``top``).

Changing the title is mostly useful in multi-process systems, for example
when a master process is forked: changing the children's title allows to
identify the task each process is busy with.  The technique is used by
PostgreSQL_ and the `OpenSSH Server`_ for example.

The procedure is hardly portable across different systems.  PostgreSQL provides
a good `multi-platform implementation`__:  this module is a Python wrapper
around PostgreSQL code.

.. _PostgreSQL: http://www.postgresql.org
.. _OpenSSH Server: http://www.openssh.com/
.. __: http://doxygen.postgresql.org/ps__status_8c-source.html


Installation
------------

You can use ``easy_install`` to install the module: to perform a system-wide
installation use::

    sudo easy_install setproctitle

If you are an unprivileged user or you want to limit installation to a local
environment, you can use the command::

    easy_install -d /target/path setproctitle

Note that ``easy_install`` requires ``/target/path`` to be in your
``PYTHONPATH``.


Module content
--------------

The module exports the following functions:

``setproctitle(title)``
    Set *title* as the title for the current process.

    Note: on many platforms, setting the process title will clobber the
    ``environ`` memory area. ``os.environ`` will work as expected from within
    the Python process, but the content of the file ``/proc/PID/environ`` will
    be overwritten.  If you require this file not to be broken you can set the
    ``SPT_NOENV`` environment variable to any non-empty value: in this case
    the maximum length for the title will be limited to the length of the
    command line, but the ``environ`` file will be untouched.


``getproctitle()``
    Return the current process title.


Module status
-------------

The module can be currently compiled and effectively used on the following
platforms:

- GNU/Linux
- BSD
- MacOS X
- Windows

Note that on Windows there is no way to change the process string:
what the module does is to create a *Named Object* whose value can be read
using a tool such as `Process Explorer`_ (contribution of a more useful tool
to be used together with ``setproctitle`` would be well accepted).

The module can probably work on HP-UX, but I haven't found any to test with.
It is unlikely that it can work on Solaris instead.

.. _Process Explorer: http://technet.microsoft.com/en-us/sysinternals/bb896653.aspx


Python 3 support
----------------

As of version 1.1 the module works with Python 3.  In order to install the
module, you can use the `distribute`_ replacemente for ``easy_install``.

In order to build and test the module under Python 3, the ``Makefile``
contains some helper targets.

.. _distribute: http://pypi.python.org/pypi/distribute


Other known implementations and discussions
-------------------------------------------

- `procname`_: a module exposing the same functionality, but less portable 
  and not well packaged.
- `Issue 5672`_: where the introduction of such functionality into the stdlib
  is being discussed.

.. _procname: http://code.google.com/p/procname/
.. _Issue 5672: http://bugs.python.org/issue5672


..
    vim: set filetype=rst:


Releases history
----------------

Version 1.1.3
~~~~~~~~~~~~~

- Don't clobber environ if the variable SPT_NOENV is set (issue #16).


Version 1.1.2
~~~~~~~~~~~~~

- Find the setproctitle include file on OpenBSD (issue #11).
- Skip test with unicode if the file system encoding wouldn't make it pass
  (issue #13).


Version 1.1.1
~~~~~~~~~~~~~

- Fixed segfault when the module is imported under mod_wsgi (issue #9).


Version 1.1
~~~~~~~~~~~

- The module works correctly with Python 3.


Version 1.0.1
~~~~~~~~~~~~~

- ``setproctitle()`` works even when Python messes up with argv, e.g. when run
  with the -m option (issue #8).


Version 1.0
~~~~~~~~~~~

No major change since the previous version.  The module has been heavily used
in production environment without any problem reported, so it's time to declare
it stable.


Version 0.4
~~~~~~~~~~~

- Module works on BSD (tested on FreeBSD 7.2).

- Module works on Windows. Many thanks to `Develer`_ for providing a neat `GCC
  package for Windows with Python integration`__ that made the Windows porting
  painless.

  .. _Develer: http://www.develer.com/
  .. __: http://www.develer.com/oss/GccWinBinaries


Version 0.3
~~~~~~~~~~~

- Module works on Mac OS X 10.2. Reported working on OS X 10.6 too.


Version 0.2
~~~~~~~~~~~

- Added ``prctl()`` call on Linux >= 2.6.9 to update ``/proc/self/status``.


Version 0.1
~~~~~~~~~~~

- Initial public release.


%prep
%setup -q -n %{unmangled_name}-%{version}

%build
env CFLAGS="$RPM_OPT_FLAGS" %{python} setup.py build

%install
%{python} setup.py install --root=$RPM_BUILD_ROOT --record=INSTALLED_FILES

%clean
rm -rf $RPM_BUILD_ROOT

%files -f INSTALLED_FILES
%defattr(-,root,root)
